==> ultracopier_2.2.4.7.orig.tar.xz: ultracopier-src/plugins/Themes/Oxygen/Languages/ar/translation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar_JO">
<context>
    <name>Themes</name>
    <message>
        <location filename="../../interface.cpp" line="328"/>
        <source>Buy the Ultimate version to fund development</source>
        <translation>شراء النسخة النهائية لتمويل التنمية</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="328"/>
        <source>Register your key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="427"/>
        <source>File %1/%2, size: %3/%4</source>
        <translation>الملف %1/%2 ، الحجم: %3/%4</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="661"/>
        <source>Copy list</source>
        <translation>قائمة النسخ</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="663"/>
        <source>Move list</source>
        <translation>قائمة النقل</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1091"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>عدم الإغلاق في حاله العثور على أخطاء</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1092"/>
        <source>Never close</source>
        <translation>لا تغلق أبدا</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1093"/>
        <source>Always close</source>
        <translation>إغلاق دائم</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1095"/>
        <source>File Name, 0KB</source>
        <translation>اسم الملف ، 0KB</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1289"/>
        <location filename="../../interface.cpp" line="1301"/>
        <location filename="../../interface.cpp" line="1313"/>
        <source>Select a color</source>
        <translation>تحديد لون</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1388"/>
        <location filename="../../interface.cpp" line="1392"/>
        <location filename="../../interface.cpp" line="1394"/>
        <source>%1 %2% of %3</source>
        <translation>%1 %2% من %3</translation>
    </message>
</context>
<context>
    <name>ThemesFactory</name>
    <message>
        <location filename="../../ThemesFactory.cpp" line="284"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>عدم الإغلاق في حاله العثور على أخطاء</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="285"/>
        <source>Never close</source>
        <translation>لا تغلق أبدا</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="286"/>
        <source>Always close</source>
        <translation>إغلاق دائم</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="482"/>
        <location filename="../../ThemesFactory.cpp" line="497"/>
        <location filename="../../ThemesFactory.cpp" line="512"/>
        <source>Select a color</source>
        <translation>تحديد لون</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="44"/>
        <source>From:</source>
        <translation>من:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="74"/>
        <source>To:</source>
        <translation>الى:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="235"/>
        <source>&amp;More</source>
        <translation>&amp;تحريك</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="255"/>
        <source>&amp;Pause</source>
        <translation>&amp;مهلة</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="269"/>
        <source>&amp;Skip</source>
        <translation>&amp;تخطي</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="280"/>
        <source>&amp;Cancel</source>
        <translation>&amp;الغاء الامر</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="127"/>
        <source>Close on transfer completion</source>
        <translation>إغلاق عند إتمام النقل</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="295"/>
        <source>Limit copy speed to:</source>
        <translation>الحد من سرعه النسخ إلى:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="338"/>
        <source>Transfer list</source>
        <translation>قائمه النقل</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="361"/>
        <source>Move the selected items to the top</source>
        <translation>تحريك المواد المحددة إلى الأعلى</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="387"/>
        <source>Move up the selected items</source>
        <translation>تحريك المواد المحددة لاعلي</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="413"/>
        <source>Move down the selected items</source>
        <translation>تحريك المواد المحددة لاسفل</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="439"/>
        <source>Move the selected items to the bottom</source>
        <translation>تحريك العناصر المحددة إلى الأسفل</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="465"/>
        <source>Add file/folder</source>
        <translation>أضافه ملف/مجلد</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="494"/>
        <source>Delete the selected items</source>
        <translation>حذف المواد المحددة</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="520"/>
        <source>Search</source>
        <translation>بحث</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="549"/>
        <source>Export the transfer list</source>
        <translation>تصدير قائمه النقل</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="575"/>
        <source>Import the transfer list</source>
        <translation>استيراد قائمه النقل</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="630"/>
        <source>Previous</source>
        <translation>السابق</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="637"/>
        <source>Next</source>
        <translation>التالي</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="672"/>
        <location filename="../../interface.ui" line="741"/>
        <source>Error</source>
        <translation>الخطا</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="692"/>
        <source>Export the errors into transfer list</source>
        <translation>تصدير الأخطاء إلى قائمه النقل</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="731"/>
        <source>Source</source>
        <translation>المصدر</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="736"/>
        <source>Destination</source>
        <translation>الوجهة</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="750"/>
        <source>Interface</source>
        <translation>الواجهه</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="796"/>
        <source>Add file</source>
        <translation>اضافة ملف</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="805"/>
        <source>Add folder</source>
        <translation>اضافة مجلد</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="814"/>
        <source>Move file(s)</source>
        <translation>تحريك الملفات</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="823"/>
        <source>Move folder</source>
        <translation>تحريك المجلد</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="832"/>
        <source>Copy file(s)</source>
        <translation>نسخ الملفات</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="841"/>
        <source>Copy folder</source>
        <translation>نسخ المجلد</translation>
    </message>
</context>
<context>
    <name>themesOptions</name>
    <message>
        <location filename="../../themesOptions.ui" line="267"/>
        <source>Show dual progression</source>
        <translation>إظهار التقدم المزدوج</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="219"/>
        <source>Show speed as main information</source>
        <translation>إظهار السرعة كمعلومات رئيسيه</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="44"/>
        <source>Use</source>
        <translation>استخدام</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="173"/>
        <source>Start with the &quot;more button&quot; pushed</source>
        <translation>تبدا مع  &quot;أكثر زر&quot; دفعت</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="67"/>
        <source>Minimize on close to systray</source>
        <translation>تصغير بالقرب من الدرج النظام</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="96"/>
        <source>At the end of the copy</source>
        <translation>في نهاية النسخ</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="103"/>
        <location filename="../../themesOptions.ui" line="137"/>
        <source>Limit copy speed to</source>
        <translation>الحد من سرعه النسخ إلى</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="147"/>
        <source> KB/s</source>
        <translation>KB/s</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="53"/>
        <source>Start minimized</source>
        <translation>بدء التصغير</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="190"/>
        <source>Save position</source>
        <translation>حفظ الموضع</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="213"/>
        <source>Informations</source>
        <translation>المعلومات</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="251"/>
        <source>Display</source>
        <translation>عرض</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="257"/>
        <source>Speed with progress bar</source>
        <translation>السرعة مع شريط التقدم</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="287"/>
        <source>Progression color</source>
        <translation>تدرج اللون</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="306"/>
        <source>Click to edit the color</source>
        <translation>انقر لتحرير اللون</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="277"/>
        <source>Show progression in the title</source>
        <translation>إظهار التقدم في العنوان</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="183"/>
        <source>Always on top</source>
        <translation>دائما في القمه</translation>
    </message>
</context>
</TS>

==> ultracopier_2.2.6.0.orig.tar.xz: ultracopier-src/plugins/Themes/Oxygen/Languages/ar/translation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar_JO">
<context>
    <name>Themes</name>
    <message>
        <location filename="../../interface.cpp" line="341"/>
        <source>Buy the Ultimate version to fund development</source>
        <translation>شراء النسخة النهائية لتمويل التنمية</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="341"/>
        <source>Register your key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="440"/>
        <source>File %1/%2, size: %3/%4</source>
        <translation>الملف %1/%2 ، الحجم: %3/%4</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="674"/>
        <source>Copy list</source>
        <translation>قائمة النسخ</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="676"/>
        <source>Move list</source>
        <translation>قائمة النقل</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1117"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>عدم الإغلاق في حاله العثور على أخطاء</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1118"/>
        <source>Never close</source>
        <translation>لا تغلق أبدا</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1119"/>
        <source>Always close</source>
        <translation>إغلاق دائم</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1121"/>
        <source>File Name, 0KB</source>
        <translation>اسم الملف ، 0KB</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1395"/>
        <location filename="../../interface.cpp" line="1407"/>
        <location filename="../../interface.cpp" line="1419"/>
        <source>Select a color</source>
        <translation>تحديد لون</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1494"/>
        <location filename="../../interface.cpp" line="1498"/>
        <location filename="../../interface.cpp" line="1500"/>
        <source>%1 %2% of %3</source>
        <translation>%1 %2% من %3</translation>
    </message>
</context>
<context>
    <name>ThemesFactory</name>
    <message>
        <location filename="../../ThemesFactory.cpp" line="294"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>عدم الإغلاق في حاله العثور على أخطاء</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="295"/>
        <source>Never close</source>
        <translation>لا تغلق أبدا</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="296"/>
        <source>Always close</source>
        <translation>إغلاق دائم</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="510"/>
        <location filename="../../ThemesFactory.cpp" line="525"/>
        <location filename="../../ThemesFactory.cpp" line="540"/>
        <source>Select a color</source>
        <translation>تحديد لون</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="44"/>
        <source>From:</source>
        <translation>من:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="74"/>
        <source>To:</source>
        <translation>الى:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="235"/>
        <source>&amp;More</source>
        <translation>&amp;تحريك</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="255"/>
        <source>&amp;Pause</source>
        <translation>&amp;مهلة</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="269"/>
        <source>&amp;Skip</source>
        <translation>&amp;تخطي</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="280"/>
        <source>&amp;Cancel</source>
        <translation>&amp;الغاء الامر</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="127"/>
        <source>Close on transfer completion</source>
        <translation>إغلاق عند إتمام النقل</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="295"/>
        <source>Limit copy speed to:</source>
        <translation>الحد من سرعه النسخ إلى:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="338"/>
        <source>Transfer list</source>
        <translation>قائمه النقل</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="361"/>
        <source>Move the selected items to the top</source>
        <translation>تحريك المواد المحددة إلى الأعلى</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="387"/>
        <source>Move up the selected items</source>
        <translation>تحريك المواد المحددة لاعلي</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="413"/>
        <source>Move down the selected items</source>
        <translation>تحريك المواد المحددة لاسفل</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="439"/>
        <source>Move the selected items to the bottom</source>
        <translation>تحريك العناصر المحددة إلى الأسفل</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="465"/>
        <source>Add file/folder</source>
        <translation>أضافه ملف/مجلد</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="494"/>
        <source>Delete the selected items</source>
        <translation>حذف المواد المحددة</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="520"/>
        <source>Search</source>
        <translation>بحث</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="549"/>
        <source>Export the transfer list</source>
        <translation>تصدير قائمه النقل</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="575"/>
        <source>Import the transfer list</source>
        <translation>استيراد قائمه النقل</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="630"/>
        <source>Previous</source>
        <translation>السابق</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="637"/>
        <source>Next</source>
        <translation>التالي</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="672"/>
        <location filename="../../interface.ui" line="741"/>
        <source>Error</source>
        <translation>الخطا</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="692"/>
        <source>Export the errors into transfer list</source>
        <translation>تصدير الأخطاء إلى قائمه النقل</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="731"/>
        <source>Source</source>
        <translation>المصدر</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="736"/>
        <source>Destination</source>
        <translation>الوجهة</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="750"/>
        <source>Interface</source>
        <translation>الواجهه</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="796"/>
        <source>Add file</source>
        <translation>اضافة ملف</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="805"/>
        <source>Add folder</source>
        <translation>اضافة مجلد</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="814"/>
        <source>Move file(s)</source>
        <translation>تحريك الملفات</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="823"/>
        <source>Move folder</source>
        <translation>تحريك المجلد</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="832"/>
        <source>Copy file(s)</source>
        <translation>نسخ الملفات</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="841"/>
        <source>Copy folder</source>
        <translation>نسخ المجلد</translation>
    </message>
</context>
<context>
    <name>themesOptions</name>
    <message>
        <location filename="../../themesOptions.ui" line="402"/>
        <source>Show dual progression</source>
        <translation>إظهار التقدم المزدوج</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="219"/>
        <source>Show speed as main information</source>
        <translation>إظهار السرعة كمعلومات رئيسيه</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="44"/>
        <source>Use</source>
        <translation>استخدام</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="173"/>
        <source>Start with the &quot;more button&quot; pushed</source>
        <translation>تبدا مع  &quot;أكثر زر&quot; دفعت</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="67"/>
        <source>Minimize on close to systray</source>
        <translation>تصغير بالقرب من الدرج النظام</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="96"/>
        <source>At the end of the copy</source>
        <translation>في نهاية النسخ</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="103"/>
        <location filename="../../themesOptions.ui" line="137"/>
        <source>Limit copy speed to</source>
        <translation>الحد من سرعه النسخ إلى</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="147"/>
        <source> KB/s</source>
        <translation>KB/s</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="53"/>
        <source>Start minimized</source>
        <translation>بدء التصغير</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="190"/>
        <source>Save position</source>
        <translation>حفظ الموضع</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="251"/>
        <source>Display</source>
        <translation>عرض</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="368"/>
        <source>Speed with progress bar</source>
        <translation>السرعة مع شريط التقدم</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="378"/>
        <source>Progression color</source>
        <translation>تدرج اللون</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="395"/>
        <source>General margin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="425"/>
        <source>General spacing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="269"/>
        <source>Click to edit the color</source>
        <translation>انقر لتحرير اللون</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="213"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="388"/>
        <source>Show progression in the title</source>
        <translation>إظهار التقدم في العنوان</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="183"/>
        <source>Always on top</source>
        <translation>دائما في القمه</translation>
    </message>
</context>
</TS>
